Generates offensive quotes

Small documentation:

The "ru()" method invokes a quote in Russian
The "en()" method invokes a quote in English

Example:

import insultsmode

print(insultsmode.ru())
print(insultsmode.en())
